@@ -3,6 +3,7 @@ import xml.etree.ElementTree as ET
 import re
 import sqlite3
 import os
+from Util.Mysqlite import create_database
 
 class Parse:
     def __init__(self,source_code):
@@ -181,26 +182,16 @@ class Parse:
             result.append(d)
         return result
 
-class Save:
-
-    def __init__(self,savepath):
-        self.savepath=savepath
-
-
-    def createdb(self):
-        conn = sqlite3.connect(self.savepath)
-        c = conn.cursor()
-        c.execute('''CREATE TABLE brief
+class Javdb_Sqlite:
+    SQLITE_TABLE_BRIEF='''CREATE TABLE brief
               (uid             TEXT PRIMARY KEY ,
                title           TEXT,
                date        CHAR(10),
                javdb_link        CHAR(50),
                img          TEXT,
                tags         TEXT
-               );''')
-        conn.commit()
-        print("成功创建表 briefinfo")
-        c.execute('''CREATE TABLE detail
+               );'''
+    SQLITE_TABLE_DETAIL='''CREATE TABLE detail
               (id             TEXT PRIMARY KEY ,
                date           CHAR(10),
                runtime        INTEGER DEFAULT 0,
@@ -221,12 +212,14 @@ class Save:
                bigimage       TEXT,
                previewimages  TEXT,
                magnets        TEXT
-               );''')
+               );'''
+    def __init__(self,savepath):
+        self.savepath=savepath
 
-        conn.commit()
-        print("成功创建表 detailinfo")
-        conn.close()
 
+    def createdb(self):
+        create_database(self.savepath,self.SQLITE_TABLE_BRIEF)
+        create_database(self.savepath,self.SQLITE_TABLE_DETAIL)
 
 
     def save(self, detailinfo):
